@@ -6,12 +6,16 @@ async function sleep(ms) {
 
 async function command(receiver, action, power, duration) {
 	let token = window.location.hash.substring(7);
-	let url = "/remoshock/command?token=" + escape(token)
-            + "&receiver=" + escape(receiver)
+	let url = "/remoshock/command"
+            + "?receiver=" + escape(receiver)
             + "&action=" + escape(action)
             + "&power=" + escape(power)
             + "&duration=" + escape(duration);
-	return fetch(url);
+	return fetch(url, {
+		headers: {
+			Authorization: "bearer " + token
+		}
+	});
 }
 
 
